

I would like this to be added to the list of known wikis:

---
- name: shortnamenospaceallsmall
- url: 'https://top.level.tld' #ex: https://wiki.site.org
- searchstring: '/?parameter1=value1&parameter2=' #the search term will be prepended to this; ex: /?search=
---

**DO TEST these values with the -u and -s options, and by adding them to the wikis.yaml file on your machine**

**Explain why this wiki is useful**
